#!/usr/bin/env python
# DressUp Enroll by Mike Cook
 
from rc522rfid import Rc522rfid
import pygame
import os

pygame.init() # initialise graphics interface  

os.environ['SDL_VIDEO_WINDOW_POS'] = 'center'
pygame.display.set_caption("Dress Up")
pygame.event.set_allowed(None)
pygame.event.set_allowed([pygame.KEYDOWN,pygame.QUIT])
pygame.key.set_repeat(500, 80)

screenWidth = 240 
screenHeight = 550 
screen = pygame.display.set_mode([screenWidth,screenHeight],0,32)
needsRedraw = True
enrol = False

rfidReader = Rc522rfid()

def main():
   global xPlot,yPlot,done,enrol,needsRedraw
   print ("Dress up doll - Enrolling Cards")
   print ("Use cursor keys to get the garment into position")
   print ("Space - next one, e - Enroll card")
   init()
   xPlot = int(screenWidth / 4)
   yPlot = int(screenHeight / 4)
   while 1:
      checkForEvent()
      for i in range(1,len(clothes)):
         done = False
         needsRedraw = True
         while not done:
           checkForEvent()    
           if needsRedraw:  
             drawScreen(i)
         if enrol :
             enrol = False
             print("enrolling")
             enrolCard(cList[i])
  
def drawScreen(i):
   global needsRedraw
   pygame.draw.rect(screen,(210,210,210),(0,0,screenWidth,screenHeight),0)
   screen.blit(clothes[0],(0,0))
   screen.blit(clothes[i],(xPlot,yPlot)) 
   pygame.display.update()
   needsRedraw = False
   
def init():
   global clothes,cList
   path = os.path.realpath(__file__) 
   path = os.path.dirname(path) + "/doll/"
   #get a list of files
   cList = [fn for fn in next(os.walk(path))[2]]
   list.sort(cList) # put in alphabetical order
   clothes = [ pygame.image.load("doll/"+cList[i]).convert_alpha()
                  for i in range(0,len(cList))]

def enrolCard(name):
   print("Enrolling", name, "place a card on the reader")
   data1 = [] ; data2 = []
   for i in range(0,16): # fill with a sectors worth of zeros
      data1.append(0) ; data2.append(0)
   for i in range(0,len(name)):
      data1[i] = ord(name[i])
   #save position of this item   
   data2[0] = xPlot >> 8
   data2[1] = xPlot & 0xFF
   data2[2] = yPlot >> 8
   data2[3] = yPlot & 0xFF
        
   # This is the (default) key for authentication
   key = [0xFF,0xFF,0xFF,0xFF,0xFF,0xFF]
   rfidReader.RC522_WriteSector(key,8,data1)
   rfidReader.RC522_WriteSector(key,9,data2)   
   print("finished enrolling\n")

def terminate(): # close down the program
    print ("Closing down")
    pygame.quit() # close pygame
    os._exit(1)
    
def checkForEvent(): # see if we need to quit
    global xPlot,yPlot,needsRedraw,done,enrol
    event = pygame.event.poll()
    if event.type == pygame.QUIT :
         terminate()
    if event.type == pygame.KEYDOWN :
       if event.key == pygame.K_ESCAPE :
          terminate()
       if event.key == pygame.K_SPACE :
          done = True
          enroll = False
       if event.key == pygame.K_e :
          done = True
          enrol = True
       if event.key == pygame.K_UP :
          yPlot -= 1
          needsRedraw = True
       if event.key == pygame.K_DOWN :
          yPlot += 1
          needsRedraw = True
       if event.key == pygame.K_RIGHT :
          xPlot += 1
          needsRedraw = True
       if event.key == pygame.K_LEFT :
          xPlot -= 1
          needsRedraw = True
          
# Main program logic:
if __name__ == '__main__':    
    main()
