#!/usr/bin/env python
# DressUp by Mike Cook
 
from rc522rfid import Rc522rfid
import pygame
import os

pygame.init() # initialise graphics interface  

os.environ['SDL_VIDEO_WINDOW_POS'] = 'center'
pygame.display.set_caption("Dress Up")
pygame.event.set_allowed(None)
pygame.event.set_allowed([pygame.KEYDOWN,pygame.QUIT])
pygame.key.set_repeat(500, 80)

screenWidth = 240 
screenHeight = 550 
screen = pygame.display.set_mode([screenWidth,screenHeight],0,32)
xPlot= [0] ; yPlot = [0] ; garment = [0] # list of what to display

rfidReader = Rc522rfid()

def main():
   global xPlot,yPlot,done,enroll
   print ("Dress up doll")
   print ("Space bar to start over")
   init()
   drawScreen()
   while 1:
      checkForEvent()
      readCard()
      if needsRedraw:  
         drawScreen()
         rfidReader.RC522_WaitForCardRemoved()

def readCard():
   global needsRedraw
   status = -1
   while status == -1:
     checkForEvent() # allow pygame a lookin while waitig for card
     status = rfidReader.RC522_ReadCard()
   # This is the (default) key for authentication
   key = [0xFF,0xFF,0xFF,0xFF,0xFF,0xFF]
   block1 = rfidReader.RC522_GetSector(key,8)
   block2 = rfidReader.RC522_GetSector(key,9)
   if block1 != -1 and block2 != -1: # if data OK
      x = block2[0] << 8 | block2[1]
      y = block2[2] << 8 | block2[3]
      lookAtNew(block1,x,y)
      needsRedraw = True
      return -1
   else:
      return("Error in reading card")
   
def lookAtNew(s1,x,y): # look at the new element
   global garment,xPlot,yPlot
   name = ""
   i = 0
   notDone = True
   while notDone and i < 16:
      c = s1[i]
      i+=1
      if c !=0:     
        name = name + chr(c)
      else:
        notDone = False
   #Look up name in list of files
   for i in range(1,len(cList)):
      if cList[i] == name: # find the name on the card
         # remove if already in the list 
         if i in garment:
            place = garment.index(i)
            del garment[place]
            del xPlot[place]
            del yPlot[place]
         else:                 # otherwise add it
            garment.append(i)
            xPlot.append(x)
            yPlot.append(y) 
   
def drawScreen():
   global needsRedraw
   #screen.blit(backImage[background],(0,0)) #if you have a background
   pygame.draw.rect(screen,(210,210,210),(0,0,screenWidth,screenHeight),0)
   for g in range(0,len(garment)):
     screen.blit(clothes[garment[g]],(xPlot[g],yPlot[g])) 
   pygame.display.update()
   needsRedraw = False
   
def init():
   global clothes,cList
   path = os.path.realpath(__file__) # path of this program
   path = os.path.dirname(path) + "/doll/" # path of images
   #get a list of files
   cList = [fn for fn in next(os.walk(path))[2]]
   list.sort(cList) # put in alphbetical order
   clothes = [ pygame.image.load("doll/"+cList[i]).convert_alpha()
                  for i in range(0,len(cList))]

def terminate(): # close down the program
    print ("Closing down")
    pygame.quit() # close pygame
    os._exit(1)
    
def checkForEvent(): # see if we need to quit
    global xPlot,yPlot,garment
    event = pygame.event.poll()
    if event.type == pygame.QUIT :
         terminate()
    if event.type == pygame.KEYDOWN :
       if event.key == pygame.K_ESCAPE :
          terminate()
       if event.key == pygame.K_SPACE :
          xPlot = [0] ; yPlot = [0]
          garment = [0] # clear lists
          drawScreen()
          
# Main program logic:
if __name__ == '__main__':    
    main()
